gkm.deviance package
====================

Submodules
----------

gkm.deviance.base module
------------------------

.. automodule:: gkm.deviance.base
   :members:
   :undoc-members:
   :show-inheritance:

gkm.deviance.binom module
-------------------------

.. automodule:: gkm.deviance.binom
   :members:
   :undoc-members:
   :show-inheritance:

gkm.deviance.exponential module
-------------------------------

.. automodule:: gkm.deviance.exponential
   :members:
   :undoc-members:
   :show-inheritance:

gkm.deviance.gaussian module
----------------------------

.. automodule:: gkm.deviance.gaussian
   :members:
   :undoc-members:
   :show-inheritance:

gkm.deviance.negbinom module
----------------------------

.. automodule:: gkm.deviance.negbinom
   :members:
   :undoc-members:
   :show-inheritance:

gkm.deviance.poisson module
---------------------------

.. automodule:: gkm.deviance.poisson
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: gkm.deviance
   :members:
   :undoc-members:
   :show-inheritance:
